@@ -45,13 +45,16 @@ class FileProcessor(ABC):
                 sysout(f'Uploading files from "{f_path}" to Firebase ...')
                 all_files = next(os.walk(f_path))[2]
                 print('Cur Dir: ' + os.getcwd())
+                print('   Glob: ' + glob_exp)
                 print(' Target: ' + f_path)
                 print('  Files: [' + '  '.join(all_files) + ']')
                 for file in all_files:
                     filename = os.path.join(f_path, file)
-                    if os.path.isfile(filename) and fnmatch(file, glob_exp):
+                    if os.path.isfile(filename) and fnmatch(filename, glob_exp):
                         f_entry = FileProcessor._read_and_encode(filename)
                         data.append(f_entry)
+                    else:
+                        sysout(f'not a file or not match: {filename}')
         if data and len(data) > 0:
             payload = FileProcessor._to_json(data)
             response = put(url, payload)
